@@ -1,7 +1,7 @@
 package T33;
 use Object::Simple;
 
-sub m1 : Attr { translate => 'm1' }
+sub m1 : Translate { target => 'm1' }
 
 Object::Simple->build_class;
 
