@@ -1,3 +1,3 @@
 package PBook;
 use Object::Simple( base => 'Book' );
-Object::Simple->end;
+Object::Simple->build_class;
